==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/outputs/GetLogDataProtectionPolicyDocumentStatementOperation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property audit Configures the detection of sensitive data.
 * @property deidentify Configures the masking of sensitive data.
 * > Every policy statement must specify exactly one operation.
 */
public data class GetLogDataProtectionPolicyDocumentStatementOperation(
    public val audit: GetLogDataProtectionPolicyDocumentStatementOperationAudit? = null,
    public val deidentify: GetLogDataProtectionPolicyDocumentStatementOperationDeidentify? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.cloudwatch.outputs.GetLogDataProtectionPolicyDocumentStatementOperation):
            GetLogDataProtectionPolicyDocumentStatementOperation =
            GetLogDataProtectionPolicyDocumentStatementOperation(
                audit = javaType.audit().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAudit.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                deidentify = javaType.deidentify().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationDeidentify.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/outputs/GetLogDataProtectionPolicyDocumentStatementOperation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property audit Configures the detection of sensitive data.
 * @property deidentify Configures the masking of sensitive data.
 * > Every policy statement must specify exactly one operation.
 */
public data class GetLogDataProtectionPolicyDocumentStatementOperation(
    public val audit: GetLogDataProtectionPolicyDocumentStatementOperationAudit? = null,
    public val deidentify: GetLogDataProtectionPolicyDocumentStatementOperationDeidentify? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.cloudwatch.outputs.GetLogDataProtectionPolicyDocumentStatementOperation): GetLogDataProtectionPolicyDocumentStatementOperation =
            GetLogDataProtectionPolicyDocumentStatementOperation(
                audit = javaType.audit().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAudit.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                deidentify = javaType.deidentify().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationDeidentify.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
